// Copyright (C) 2023 WYATT GROUP
// Please see the AUTHORS file for details.
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <https://www.gnu.org/licenses/>.

import 'package:flutter/material.dart';
import 'package:wyatt_ui_components/wyatt_ui_components.dart';

/// {@template loader_theme_extension_default}
/// The default [LoaderThemeExtension].
/// {@endtemplate}
class LoaderThemeExtensionDefault extends LoaderThemeExtension {
  /// {@macro loader_theme_extension_default}
  const LoaderThemeExtensionDefault({
    required super.colors,
    required super.stroke,
  });

  /// Creates a [LoaderThemeExtensionDefault] from a [ThemeData]
  /// and opinionated defaults.
  ///
  /// {@macro card_theme_extension_default}
  factory LoaderThemeExtensionDefault.from(ThemeData theme) =>
      LoaderThemeExtensionDefault(
        colors: MultiColor([
          theme.progressIndicatorTheme.color ?? theme.colorScheme.primary,
          Colors.transparent,
        ]),
        stroke: 4,
      );

  /// Creates a [LoaderThemeExtensionDefault] from a dark [ThemeData]
  factory LoaderThemeExtensionDefault.dark() =>
      LoaderThemeExtensionDefault.from(ThemeData.dark());

  /// Creates a [LoaderThemeExtensionDefault] from a light [ThemeData]
  factory LoaderThemeExtensionDefault.light() =>
      LoaderThemeExtensionDefault.from(ThemeData.light());
}
