// Copyright (C) 2023 WYATT GROUP
// Please see the AUTHORS file for details.
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <https://www.gnu.org/licenses/>.

import 'package:flutter/material.dart';

class RichTextBuilderThemeExtension
    extends ThemeExtension<RichTextBuilderThemeExtension> {
  const RichTextBuilderThemeExtension({
    this.defaultStyle,
    this.styles,
  });

  /// Default TextStyle used in this rich text component.
  final TextStyle? defaultStyle;

  /// Used styles in this rich text component.
  final Map<String, TextStyle>? styles;

  @override
  ThemeExtension<RichTextBuilderThemeExtension> copyWith({
    TextStyle? defaultStyle,
    Map<String, TextStyle>? styles,
  }) =>
      RichTextBuilderThemeExtension(
        defaultStyle: defaultStyle ?? this.defaultStyle,
        styles: styles ?? this.styles,
      );

  @override
  ThemeExtension<RichTextBuilderThemeExtension> lerp(
    covariant ThemeExtension<RichTextBuilderThemeExtension>? other,
    double t,
  ) {
    if (other is! RichTextBuilderThemeExtension) {
      return this;
    }
    return RichTextBuilderThemeExtension(
      defaultStyle: TextStyle.lerp(defaultStyle, other.defaultStyle, t),
      styles: styles,
    );
  }
}
